# 4FreqVariablesPlot.py
#
# This script and the data files freq*.csv produce Figure 3 in Rowlinson et al. 2022
# It uses the data files that are output by the generalised script FilterVariables.py from the
# Github repository TraP_tools https://github.com/transientskp/TraP_tools
#

import scipy as sp
import numpy as np
import pandas as pd
import sys
import matplotlib
import matplotlib.pyplot as plt
import pylab
pylab.rcParams['legend.loc'] = 'best'
from matplotlib.ticker import NullFormatter
from matplotlib.font_manager import FontProperties

matplotlib.rcParams.update({'font.size': 18})
matplotlib.rcParams['axes.linewidth'] = 2
matplotlib.rcParams['xtick.major.size'] = 10
matplotlib.rcParams['ytick.major.size'] = 10
matplotlib.rcParams['xtick.major.width'] = 2
matplotlib.rcParams['ytick.major.width'] = 2

Freq0='0.96 GHz'
Freq1='1.18 GHz'
Freq2='1.39 GHz'
Freq3='1.61 GHz'

Freq0_eta_cut=8.22
Freq1_eta_cut=16.5
Freq2_eta_cut=13.5
Freq3_eta_cut=50.2

Freq0_V_cut=0.203
Freq1_V_cut=0.196
Freq2_V_cut=0.204
Freq3_V_cut=0.179

Freq0_data=pd.read_csv('freq0_data.csv')
Freq1_data=pd.read_csv('freq1_data.csv')
Freq2_data=pd.read_csv('freq2_data.csv')
Freq3_data=pd.read_csv('freq3_data.csv')

# Creating eta V plot
nullfmt   = NullFormatter()         # no labels
fontP = FontProperties()
fontP.set_size('large')
fig = plt.figure(1,figsize=(12,12))
ax1 = fig.add_subplot(221)
ax2 = fig.add_subplot(222)
ax3 = fig.add_subplot(223)
ax4 = fig.add_subplot(224)
plt.tight_layout()
fig.subplots_adjust(hspace=0,wspace=0)

#plt.xlabel(r'$\eta_{\nu}$', fontsize=28)
#plt.ylabel(r'$V_{\nu}$', fontsize=28)
ax1.xaxis.set_major_formatter(nullfmt)
ax1.axes.xaxis.set_ticklabels([])

ax2.xaxis.set_major_formatter(nullfmt)
ax2.yaxis.set_major_formatter(nullfmt)
ax2.axes.xaxis.set_ticklabels([])
ax2.axes.yaxis.set_ticklabels([])

ax4.yaxis.set_major_formatter(nullfmt)
ax4.axes.yaxis.set_ticklabels([])

ax1.scatter(Freq0_data['eta'],Freq0_data['V'], s=20.)
ax1.axhline(Freq0_V_cut, linewidth=2, color='k', linestyle='--')
ax1.axvline(Freq0_eta_cut, linewidth=2, color='k', linestyle='--')
ax1.plot([69.4], [1.56], marker='o', markersize=20, fillstyle='none', markeredgecolor='r') # MAXI J1820+70
ax1.plot([37.5, 756, 21.6], [0.203,0.185,0.0992], marker='D', markersize=15, fillstyle='none', markeredgecolor='r', linestyle='none') # Other Variables
ax1.scatter([0.634,0.406,0.375,0.375,0.443,0.431,0.568,0.537,0.673,0.462,0.403,1.912,0.451],[0.243,0.224,0.226,0.285,0.393,0.311,0.395,0.321,0.353,0.195,0.270,0.574,0.331], s=30., c='r', marker='+') # Transient candidate sources

ax1.text(45,1.56,'1', fontsize=14)
ax1.text(24,0.203,'2', fontsize=14)
ax1.text(490,0.185,'3', fontsize=14)
ax1.text(14,0.0992,'4', fontsize=14)


ax2.scatter(Freq1_data['eta'],Freq1_data['V'], s=20.)
ax2.axhline(Freq1_V_cut, linewidth=2, color='k', linestyle='--')
ax2.axvline(Freq1_eta_cut, linewidth=2, color='k', linestyle='--')
ax2.plot([131], [1.43],  marker='o', markersize=20, fillstyle='none', markeredgecolor='r') # MAXI J1820+70
ax2.plot([48.8, 484, 60.1], [0.265,0.201,0.157], marker='D', markersize=15, fillstyle='none', markeredgecolor='r', linestyle='none') # Other Variables
ax2.scatter([0.681,0.441,0.508,0.329,0.341,0.410,0.466,0.600,0.654,0.653,0.990,1.044,0.487],[0.308,0.270,0.364,0.310,0.434,0.339,0.513,0.331,0.421,0.293,0.517,0.519,0.495], s=30., c='r', marker='+') # Transient candidate sources

ax2.text(85,1.43,'1', fontsize=14)
ax2.text(31,0.265,'2', fontsize=14)
ax2.text(314,0.201,'3', fontsize=14)
ax2.text(39,0.157,'4', fontsize=14)

ax3.scatter(Freq2_data['eta'],Freq2_data['V'], s=20.)
ax3.axhline(Freq2_V_cut, linewidth=2, color='k', linestyle='--')
ax3.axvline(Freq2_eta_cut, linewidth=2, color='k', linestyle='--')
ax3.plot([325], [1.66],  marker='o', markersize=20, fillstyle='none', markeredgecolor='r') # MAXI J1820+70
ax3.plot([123, 384, 225], [0.340,0.167,0.222], marker='D', markersize=15, fillstyle='none', markeredgecolor='r', linestyle='none') # Other Variables
ax3.scatter([0.312,0.380,0.346,0.442,0.688,0.439,0.498,0.531,0.488,0.511,0.454,0.522,0.493],[0.180,0.201,0.223,0.248,0.321,0.246,0.343,0.183,0.265,0.241,0.309,0.432,0.420], s=30., c='r', marker='+') # Transient candidate sources

ax3.text(211,1.66,'1', fontsize=14)
ax3.text(79,0.304,'2', fontsize=14)
ax3.text(249,0.167,'3', fontsize=14)
ax3.text(146,0.222,'4', fontsize=14)

ax4.scatter(Freq3_data['eta'],Freq3_data['V'], s=20.)
ax4.axhline(Freq3_V_cut, linewidth=2, color='k', linestyle='--')
ax4.axvline(Freq3_eta_cut, linewidth=2, color='k', linestyle='--')
ax4.plot([168], [1.45], marker='o', markersize=20, fillstyle='none', markeredgecolor='r') # MAXI J1820+70
ax4.plot([29.3, 235, 63.2], [0.410,0.206,0.205], marker='D', markersize=15, fillstyle='none', markeredgecolor='r', linestyle='none') # Other Variables
ax4.scatter([0.413,0.517,0.396,0.451,0.582,0.526,0.569,0.383,0.412,0.632,0.352,0.511,0.416],[0.551,0.658,0.621,0.576,0.583,0.581,0.751,0.395,0.671,0.492,0.990,1.020,0.854], s=30., c='r', marker='+') # Transient candidate sources

ax4.text(109,1.45,'1', fontsize=14)
ax4.text(19,0.410,'2', fontsize=14)
ax4.text(152,0.206,'3', fontsize=14)
ax4.text(41,0.205,'4', fontsize=14)

ax1.text(0.25,1.5,Freq0, fontsize=20)
ax2.text(0.25,1.5,Freq1, fontsize=20)
ax3.text(0.25,1.5,Freq2, fontsize=20)
ax4.text(0.25,1.5,Freq3, fontsize=20)



all_etas=list(Freq0_data['eta'])+list(Freq1_data['eta'])+list(Freq2_data['eta'])+list(Freq3_data['eta'])
all_Vs=list(Freq0_data['V'])+list(Freq1_data['V'])+list(Freq2_data['V'])+list(Freq3_data['V'])

xmin=min(all_etas)*0.8
xmax=max(all_etas)*1.4
ymin=min(all_Vs)*0.8
ymax=max(all_Vs)*1.4

ax3.set_xlim([xmin,xmax])
ax3.set_ylim([ymin,ymax])

ax1.set_ylabel(r'$V$', fontsize=20)
ax3.set_ylabel(r'$V$', fontsize=20)
ax3.set_xlabel(r'$\eta$', fontsize=20)
ax4.set_xlabel(r'$\eta$', fontsize=20)

ax1.set_yscale('log')
ax1.set_xscale('log')
ax2.set_yscale('log')
ax2.set_xscale('log')
ax3.set_yscale('log')
ax3.set_xscale('log')
ax4.set_yscale('log')
ax4.set_xscale('log')

ax1.set_xlim( ax3.get_xlim() )
ax1.set_ylim( ax3.get_ylim() )
ax2.set_xlim( ax3.get_xlim() )
ax2.set_ylim( ax3.get_ylim() )
ax4.set_ylim( ax3.get_ylim() )
ax4.set_xlim( ax3.get_xlim() )
ax1.xaxis.set_major_formatter(nullfmt)
ax4.yaxis.set_major_formatter(nullfmt)
ax2.xaxis.set_major_formatter(nullfmt)
ax2.yaxis.set_major_formatter(nullfmt)

plt.savefig('eta_V_plots.png')
