# plotLightcurve_psr.py
#
# This script creates Figure 6 in in Rowlinson et al. 2022
# This plots the lightcurve of the pulsar using data output by TraP
# The original database querying code is there for reference and the
# datafiles are included to reproduce the plot

# Import all the dependencies and generic setup
import scipy as sp
import numpy as np
import pandas as pd
#import logging
#logging.basicConfig(level=logging.INFO)
#query_loglevel = logging.WARNING  # Set to INFO to see queries, otherwise WARNING
import sys
sys.path.append('../')
from databaseTools import dbtools
from tools import tools
from plotting import plot_varib_params as pltvp
import matplotlib
import matplotlib.pyplot as plt
import pylab
pylab.rcParams['legend.loc'] = 'best'
from matplotlib.ticker import NullFormatter
from matplotlib.font_manager import FontProperties
from astropy import units as u
from astropy.coordinates import SkyCoord
from datetime import datetime


matplotlib.rcParams.update({'font.size': 18})
matplotlib.rcParams['axes.linewidth'] = 2
matplotlib.rcParams['xtick.major.size'] = 10
matplotlib.rcParams['ytick.major.size'] = 10
matplotlib.rcParams['xtick.major.width'] = 2
matplotlib.rcParams['ytick.major.width'] = 2



TraP_version = False # are you using the TraP database directly?
sourceID = 8952
datafile = str(sourceID)+'_lightcurve.csv'
freqs = pd.DataFrame(data=[[0.963,'r']],
                          columns = ['freq','colour'])
outname = str(sourceID)+'_lightcurve.png' # name of the plotdata datafile

if TraP_version:
    from sqlalchemy import *
    from sqlalchemy.orm import relationship
    import tkp.db # the TraP code
    from tkp.db.model import Extractedsource
    from tkp.db.model import Assocxtrsource
    from tkp.db.model import Image
    from dblogin import * # This file contains all the variables required to connect to the database, see the example here: https://github.com/transientskp/TraP_tools/blob/master/exampleScripts/dblogin.py



if TraP_version:
    # The input database, dataset and thresholds
    dataset = 33
    database = 'AR_testing4'
    
    # Connect to the database and run the queries
    session = dbtools.access(engine,host,port,user,password,database)
    
    flxVals = session.query(Assocxtrsource,Extractedsource).select_from(join(Assocxtrsource,Extractedsource)).filter(Assocxtrsource.runcat_id == sourceID).all()
    lightcurve = pd.DataFrame(data=[[flxVals[x].Extractedsource.image.id, flxVals[x].Extractedsource.f_int, flxVals[x].Extractedsource.f_int_err, flxVals[x].Extractedsource.det_sigma] for x in range(len(flxVals))], columns = ['Image','Flux','FluxErr','sigma'])

    images= session.query(Image).all()
    images = pd.DataFrame(data=[[images[x].id,images[x].taustart_ts,np.around(images[x].band.freq_central/1e9, decimals=3)] for x in range(len(images))], columns=['Image','Time','Freq'])

    lightcurve = pd.merge(lightcurve, images, on="Image")
    lightcurve.to_csv(datafile)
else:
    lightcurve = pd.read_csv(datafile, header=0)
    lightcurve['Time'] = lightcurve['Time'].apply(lambda x: datetime.strptime(x, "%Y-%m-%d %H:%M:%S.%f"))

starttime = min(lightcurve.Time)



# Creating lightcurve plot
nullfmt   = NullFormatter()         # no labels
fontP = FontProperties()
fontP.set_size('large')
fig = plt.figure(1,figsize=(12,6))
plt.tight_layout()
fig.subplots_adjust(hspace=0,wspace=0)
ax1 = fig.add_subplot(111)


for index, row in freqs.iterrows():
    print row.freq
    lightcurveTMP = lightcurve.loc[lightcurve['Freq'] == row.freq]
    y = lightcurveTMP.Flux*1e3
    paramy, paramy2 = tools.SigmaFit(y)
    range_y,fity = pltvp.gaussian_fit(y,paramy2)

    sigcuty = paramy2[0] + paramy2[1]*3
     
    detections=[[row.Time-starttime,row.Flux*1e3,row.FluxErr*1e3] for index, row in lightcurveTMP.iterrows() if row.sigma >= 5.]

    x=[d[0].seconds for d in detections]
    y=[d[1] for d in detections]
    yerr=[d[2] for d in detections]
    ax1.errorbar(x,y, yerr=yerr, c='r', fmt='o', markersize=10)

    ulimits=[[row.Time-starttime,row.Flux*1e3,row.FluxErr*1e3] for index, row in lightcurveTMP.iterrows() if row.sigma < 5.]
    x=[d[0].seconds for d in ulimits]
    y=[d[1] for d in ulimits]
    yerr=[d[2] for d in ulimits]
    ax1.errorbar(x,y, yerr=yerr, c='b', fmt='v', markersize=10)   
    
ax1.set_xlabel('Time after observation start (seconds)', fontsize=16)
ax1.set_ylabel('Flux Density (mJy)', fontsize=16)
plt.savefig(outname)

exit()
    
    
